@@ -88,7 +88,10 @@ def add(path):
 
         for class_name, class_ in class_members:
             if class_name in SCANNERS:
-                print(f"Unable to add {class_name} from {path} " "due to name conflict")
+                print(
+                    f"Unable to add {class_name} from {path} "
+                    "due to name conflict"
+                )
 
             if issubclass(class_, BaseAntivirus):
                 SCANNERS[class_name] = class_
