@@ -65,7 +65,11 @@ class BaseAntivirus(abc.ABC):
 
     @bad_files.setter
     def bad_files(self, value):
-        if not isinstance(value, collections.abc.Sequence) or isinstance(value, str):
+        if (
+            not isinstance(value, collections.abc.Sequence)
+            or
+            isinstance(value, str)
+        ):
             raise ValueError("bad_files must be a sequence")
 
         for bad_file in value:
