@@ -804,6 +804,23 @@ class Manifest:
 
         return output
 
+    def get_file_page(self, start: int, length: int) -> List[Dict]:
+        """
+        Get a single page of file results.
+
+        Parameters
+        ----------
+        start : int
+            The start index for the page.
+        length : int
+            The page length.
+
+        Returns
+        -------
+        List of dicts containing file information.
+        """
+        return self.database.get_file_page(start=start, length=length)
+
     def _compute_file_info_with_pool(
         self,
         n_processes: Optional[int] = None,
