@@ -1,5 +1,8 @@
 """
 Database functionality for a file transfer manifest.
+
+An object of class Database is available via the `database` property of a
+manifest object.
 """
 
 from enum import Enum
@@ -1465,3 +1468,88 @@ class Database:
         )
         row = cursor.fetchone()
         return bool(row["error_count"])
+
+    def get_file_page(self, start: int, length: int) -> List[Dict]:
+        """
+        Get a single page of file results.
+
+        Parameters
+        ----------
+        start : int
+            The start index for the page.
+        length : int
+            The page length.
+
+        Returns
+        -------
+        List of dicts containing file information.
+        """
+        # Start by getting results of interest from the database.
+        sql = """
+        SELECT
+            File.id,
+            File.path,
+            File.size,
+            FileStatus.status,
+            File.is_folder
+        FROM
+            File
+            INNER JOIN FileStatus ON File.file_status_id = FileStatus.id
+        WHERE
+            File.path IS NOT NULL
+        LIMIT
+            :start, :length
+        """
+        cursor = self.connection.cursor()
+        cursor.execute(sql, {
+            "start": start,
+            "length":length,
+        })
+        file_records = [
+            {
+                key: row[key]
+                for key in row.keys()
+            }
+            for row in cursor.fetchall()
+        ]
+        cursor.close()
+
+        # Next, transform the records so they contain data needed for the files
+        # list view.
+        job_data = self.get_job_data()
+        ignore_path = job_data["ignore_path"]
+        len_ignore_path = len(ignore_path)
+        hyperthought_root = job_data["hyperthought_root"].rstrip("/")
+
+        def get_hyperthought_path(file_record):
+            relative_path = (
+                file_record["path"][len_ignore_path:]
+                .replace("\\", "/")
+                .lstrip("/")
+            )
+            return f"{hyperthought_root}/{relative_path}"
+
+        def get_type(file_record):
+            if file_record["is_folder"]:
+                return "Folder"
+
+            extension = os.path.splitext(file_record["path"])[-1].strip(".")
+            return extension
+
+        def transform_record(file_record):
+            return {
+                "id": file_record["id"],
+                "local_path": file_record["path"],
+                "hyperthought_path": get_hyperthought_path(file_record),
+                "type": get_type(file_record),
+                "status": file_record["status"],
+            }
+
+        file_page = [
+            transform_record(file_record)
+            for file_record in file_records
+        ]
+
+
+        # Return the result.
+        return file_page
